# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.channel.v1",
    manifest={
        "BillingAccount",
    },
)


class BillingAccount(proto.Message):
    r"""Represents a billing account.

    Attributes:
        name (str):
            Output only. Resource name of the billing account. Format:
            accounts/{account_id}/billingAccounts/{billing_account_id}.
        display_name (str):
            Display name of the billing account.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time when this billing
            account was created.
        currency_code (str):
            Output only. The 3-letter currency code
            defined in ISO 4217.
        region_code (str):
            Output only. The CLDR region code.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    currency_code: str = proto.Field(
        proto.STRING,
        number=4,
    )
    region_code: str = proto.Field(
        proto.STRING,
        number=5,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1, operations_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore
import google.protobuf
from google.protobuf import empty_pb2  # type: ignore

from google.cloud.channel_v1 import gapic_version as package_version
from google.cloud.channel_v1.types import (
    channel_partner_links,
    customers,
    entitlements,
    offers,
    repricing,
    service,
)

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)

if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
    DEFAULT_CLIENT_INFO.protobuf_runtime_version = google.protobuf.__version__


class CloudChannelServiceTransport(abc.ABC):
    """Abstract transport class for CloudChannelService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/apps.order",)

    DEFAULT_HOST: str = "cloudchannel.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'cloudchannel.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes
        if not hasattr(self, "_ignore_credentials"):
            self._ignore_credentials: bool = False

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None and not self._ignore_credentials:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    @property
    def host(self):
        return self._host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_customers: gapic_v1.method.wrap_method(
                self.list_customers,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_customer: gapic_v1.method.wrap_method(
                self.get_customer,
                default_timeout=None,
                client_info=client_info,
            ),
            self.check_cloud_identity_accounts_exist: gapic_v1.method.wrap_method(
                self.check_cloud_identity_accounts_exist,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_customer: gapic_v1.method.wrap_method(
                self.create_customer,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_customer: gapic_v1.method.wrap_method(
                self.update_customer,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_customer: gapic_v1.method.wrap_method(
                self.delete_customer,
                default_timeout=None,
                client_info=client_info,
            ),
            self.import_customer: gapic_v1.method.wrap_method(
                self.import_customer,
                default_timeout=None,
                client_info=client_info,
            ),
            self.provision_cloud_identity: gapic_v1.method.wrap_method(
                self.provision_cloud_identity,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_entitlements: gapic_v1.method.wrap_method(
                self.list_entitlements,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_transferable_skus: gapic_v1.method.wrap_method(
                self.list_transferable_skus,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_transferable_offers: gapic_v1.method.wrap_method(
                self.list_transferable_offers,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_entitlement: gapic_v1.method.wrap_method(
                self.get_entitlement,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_entitlement: gapic_v1.method.wrap_method(
                self.create_entitlement,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.change_parameters: gapic_v1.method.wrap_method(
                self.change_parameters,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.change_renewal_settings: gapic_v1.method.wrap_method(
                self.change_renewal_settings,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.change_offer: gapic_v1.method.wrap_method(
                self.change_offer,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.start_paid_service: gapic_v1.method.wrap_method(
                self.start_paid_service,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.suspend_entitlement: gapic_v1.method.wrap_method(
                self.suspend_entitlement,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.cancel_entitlement: gapic_v1.method.wrap_method(
                self.cancel_entitlement,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.activate_entitlement: gapic_v1.method.wrap_method(
                self.activate_entitlement,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.transfer_entitlements: gapic_v1.method.wrap_method(
                self.transfer_entitlements,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.transfer_entitlements_to_google: gapic_v1.method.wrap_method(
                self.transfer_entitlements_to_google,
                default_timeout=60.0,
                client_info=client_info,
            ),
            self.list_channel_partner_links: gapic_v1.method.wrap_method(
                self.list_channel_partner_links,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_channel_partner_link: gapic_v1.method.wrap_method(
                self.get_channel_partner_link,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_channel_partner_link: gapic_v1.method.wrap_method(
                self.create_channel_partner_link,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_channel_partner_link: gapic_v1.method.wrap_method(
                self.update_channel_partner_link,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_customer_repricing_config: gapic_v1.method.wrap_method(
                self.get_customer_repricing_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_customer_repricing_configs: gapic_v1.method.wrap_method(
                self.list_customer_repricing_configs,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_customer_repricing_config: gapic_v1.method.wrap_method(
                self.create_customer_repricing_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_customer_repricing_config: gapic_v1.method.wrap_method(
                self.update_customer_repricing_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_customer_repricing_config: gapic_v1.method.wrap_method(
                self.delete_customer_repricing_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_channel_partner_repricing_config: gapic_v1.method.wrap_method(
                self.get_channel_partner_repricing_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_channel_partner_repricing_configs: gapic_v1.method.wrap_method(
                self.list_channel_partner_repricing_configs,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_channel_partner_repricing_config: gapic_v1.method.wrap_method(
                self.create_channel_partner_repricing_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_channel_partner_repricing_config: gapic_v1.method.wrap_method(
                self.update_channel_partner_repricing_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_channel_partner_repricing_config: gapic_v1.method.wrap_method(
                self.delete_channel_partner_repricing_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_sku_groups: gapic_v1.method.wrap_method(
                self.list_sku_groups,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_sku_group_billable_skus: gapic_v1.method.wrap_method(
                self.list_sku_group_billable_skus,
                default_timeout=None,
                client_info=client_info,
            ),
            self.lookup_offer: gapic_v1.method.wrap_method(
                self.lookup_offer,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_products: gapic_v1.method.wrap_method(
                self.list_products,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_skus: gapic_v1.method.wrap_method(
                self.list_skus,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_offers: gapic_v1.method.wrap_method(
                self.list_offers,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_purchasable_skus: gapic_v1.method.wrap_method(
                self.list_purchasable_skus,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_purchasable_offers: gapic_v1.method.wrap_method(
                self.list_purchasable_offers,
                default_timeout=None,
                client_info=client_info,
            ),
            self.query_eligible_billing_accounts: gapic_v1.method.wrap_method(
                self.query_eligible_billing_accounts,
                default_timeout=None,
                client_info=client_info,
            ),
            self.register_subscriber: gapic_v1.method.wrap_method(
                self.register_subscriber,
                default_timeout=None,
                client_info=client_info,
            ),
            self.unregister_subscriber: gapic_v1.method.wrap_method(
                self.unregister_subscriber,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_subscribers: gapic_v1.method.wrap_method(
                self.list_subscribers,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_entitlement_changes: gapic_v1.method.wrap_method(
                self.list_entitlement_changes,
                default_timeout=None,
                client_info=client_info,
            ),
            self.cancel_operation: gapic_v1.method.wrap_method(
                self.cancel_operation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_operation: gapic_v1.method.wrap_method(
                self.delete_operation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_operation: gapic_v1.method.wrap_method(
                self.get_operation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_operations: gapic_v1.method.wrap_method(
                self.list_operations,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def list_customers(
        self,
    ) -> Callable[
        [service.ListCustomersRequest],
        Union[service.ListCustomersResponse, Awaitable[service.ListCustomersResponse]],
    ]:
        raise NotImplementedError()

    @property
    def get_customer(
        self,
    ) -> Callable[
        [service.GetCustomerRequest],
        Union[customers.Customer, Awaitable[customers.Customer]],
    ]:
        raise NotImplementedError()

    @property
    def check_cloud_identity_accounts_exist(
        self,
    ) -> Callable[
        [service.CheckCloudIdentityAccountsExistRequest],
        Union[
            service.CheckCloudIdentityAccountsExistResponse,
            Awaitable[service.CheckCloudIdentityAccountsExistResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_customer(
        self,
    ) -> Callable[
        [service.CreateCustomerRequest],
        Union[customers.Customer, Awaitable[customers.Customer]],
    ]:
        raise NotImplementedError()

    @property
    def update_customer(
        self,
    ) -> Callable[
        [service.UpdateCustomerRequest],
        Union[customers.Customer, Awaitable[customers.Customer]],
    ]:
        raise NotImplementedError()

    @property
    def delete_customer(
        self,
    ) -> Callable[
        [service.DeleteCustomerRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def import_customer(
        self,
    ) -> Callable[
        [service.ImportCustomerRequest],
        Union[customers.Customer, Awaitable[customers.Customer]],
    ]:
        raise NotImplementedError()

    @property
    def provision_cloud_identity(
        self,
    ) -> Callable[
        [service.ProvisionCloudIdentityRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_entitlements(
        self,
    ) -> Callable[
        [service.ListEntitlementsRequest],
        Union[
            service.ListEntitlementsResponse,
            Awaitable[service.ListEntitlementsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_transferable_skus(
        self,
    ) -> Callable[
        [service.ListTransferableSkusRequest],
        Union[
            service.ListTransferableSkusResponse,
            Awaitable[service.ListTransferableSkusResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_transferable_offers(
        self,
    ) -> Callable[
        [service.ListTransferableOffersRequest],
        Union[
            service.ListTransferableOffersResponse,
            Awaitable[service.ListTransferableOffersResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_entitlement(
        self,
    ) -> Callable[
        [service.GetEntitlementRequest],
        Union[entitlements.Entitlement, Awaitable[entitlements.Entitlement]],
    ]:
        raise NotImplementedError()

    @property
    def create_entitlement(
        self,
    ) -> Callable[
        [service.CreateEntitlementRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def change_parameters(
        self,
    ) -> Callable[
        [service.ChangeParametersRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def change_renewal_settings(
        self,
    ) -> Callable[
        [service.ChangeRenewalSettingsRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def change_offer(
        self,
    ) -> Callable[
        [service.ChangeOfferRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def start_paid_service(
        self,
    ) -> Callable[
        [service.StartPaidServiceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def suspend_entitlement(
        self,
    ) -> Callable[
        [service.SuspendEntitlementRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def cancel_entitlement(
        self,
    ) -> Callable[
        [service.CancelEntitlementRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def activate_entitlement(
        self,
    ) -> Callable[
        [service.ActivateEntitlementRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def transfer_entitlements(
        self,
    ) -> Callable[
        [service.TransferEntitlementsRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def transfer_entitlements_to_google(
        self,
    ) -> Callable[
        [service.TransferEntitlementsToGoogleRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_channel_partner_links(
        self,
    ) -> Callable[
        [service.ListChannelPartnerLinksRequest],
        Union[
            service.ListChannelPartnerLinksResponse,
            Awaitable[service.ListChannelPartnerLinksResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_channel_partner_link(
        self,
    ) -> Callable[
        [service.GetChannelPartnerLinkRequest],
        Union[
            channel_partner_links.ChannelPartnerLink,
            Awaitable[channel_partner_links.ChannelPartnerLink],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_channel_partner_link(
        self,
    ) -> Callable[
        [service.CreateChannelPartnerLinkRequest],
        Union[
            channel_partner_links.ChannelPartnerLink,
            Awaitable[channel_partner_links.ChannelPartnerLink],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_channel_partner_link(
        self,
    ) -> Callable[
        [service.UpdateChannelPartnerLinkRequest],
        Union[
            channel_partner_links.ChannelPartnerLink,
            Awaitable[channel_partner_links.ChannelPartnerLink],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_customer_repricing_config(
        self,
    ) -> Callable[
        [service.GetCustomerRepricingConfigRequest],
        Union[
            repricing.CustomerRepricingConfig,
            Awaitable[repricing.CustomerRepricingConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_customer_repricing_configs(
        self,
    ) -> Callable[
        [service.ListCustomerRepricingConfigsRequest],
        Union[
            service.ListCustomerRepricingConfigsResponse,
            Awaitable[service.ListCustomerRepricingConfigsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_customer_repricing_config(
        self,
    ) -> Callable[
        [service.CreateCustomerRepricingConfigRequest],
        Union[
            repricing.CustomerRepricingConfig,
            Awaitable[repricing.CustomerRepricingConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_customer_repricing_config(
        self,
    ) -> Callable[
        [service.UpdateCustomerRepricingConfigRequest],
        Union[
            repricing.CustomerRepricingConfig,
            Awaitable[repricing.CustomerRepricingConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def delete_customer_repricing_config(
        self,
    ) -> Callable[
        [service.DeleteCustomerRepricingConfigRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def get_channel_partner_repricing_config(
        self,
    ) -> Callable[
        [service.GetChannelPartnerRepricingConfigRequest],
        Union[
            repricing.ChannelPartnerRepricingConfig,
            Awaitable[repricing.ChannelPartnerRepricingConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_channel_partner_repricing_configs(
        self,
    ) -> Callable[
        [service.ListChannelPartnerRepricingConfigsRequest],
        Union[
            service.ListChannelPartnerRepricingConfigsResponse,
            Awaitable[service.ListChannelPartnerRepricingConfigsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_channel_partner_repricing_config(
        self,
    ) -> Callable[
        [service.CreateChannelPartnerRepricingConfigRequest],
        Union[
            repricing.ChannelPartnerRepricingConfig,
            Awaitable[repricing.ChannelPartnerRepricingConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_channel_partner_repricing_config(
        self,
    ) -> Callable[
        [service.UpdateChannelPartnerRepricingConfigRequest],
        Union[
            repricing.ChannelPartnerRepricingConfig,
            Awaitable[repricing.ChannelPartnerRepricingConfig],
        ],
    ]:
        raise NotImplementedError()

    @property
    def delete_channel_partner_repricing_config(
        self,
    ) -> Callable[
        [service.DeleteChannelPartnerRepricingConfigRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def list_sku_groups(
        self,
    ) -> Callable[
        [service.ListSkuGroupsRequest],
        Union[service.ListSkuGroupsResponse, Awaitable[service.ListSkuGroupsResponse]],
    ]:
        raise NotImplementedError()

    @property
    def list_sku_group_billable_skus(
        self,
    ) -> Callable[
        [service.ListSkuGroupBillableSkusRequest],
        Union[
            service.ListSkuGroupBillableSkusResponse,
            Awaitable[service.ListSkuGroupBillableSkusResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def lookup_offer(
        self,
    ) -> Callable[
        [service.LookupOfferRequest], Union[offers.Offer, Awaitable[offers.Offer]]
    ]:
        raise NotImplementedError()

    @property
    def list_products(
        self,
    ) -> Callable[
        [service.ListProductsRequest],
        Union[service.ListProductsResponse, Awaitable[service.ListProductsResponse]],
    ]:
        raise NotImplementedError()

    @property
    def list_skus(
        self,
    ) -> Callable[
        [service.ListSkusRequest],
        Union[service.ListSkusResponse, Awaitable[service.ListSkusResponse]],
    ]:
        raise NotImplementedError()

    @property
    def list_offers(
        self,
    ) -> Callable[
        [service.ListOffersRequest],
        Union[service.ListOffersResponse, Awaitable[service.ListOffersResponse]],
    ]:
        raise NotImplementedError()

    @property
    def list_purchasable_skus(
        self,
    ) -> Callable[
        [service.ListPurchasableSkusRequest],
        Union[
            service.ListPurchasableSkusResponse,
            Awaitable[service.ListPurchasableSkusResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_purchasable_offers(
        self,
    ) -> Callable[
        [service.ListPurchasableOffersRequest],
        Union[
            service.ListPurchasableOffersResponse,
            Awaitable[service.ListPurchasableOffersResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def query_eligible_billing_accounts(
        self,
    ) -> Callable[
        [service.QueryEligibleBillingAccountsRequest],
        Union[
            service.QueryEligibleBillingAccountsResponse,
            Awaitable[service.QueryEligibleBillingAccountsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def register_subscriber(
        self,
    ) -> Callable[
        [service.RegisterSubscriberRequest],
        Union[
            service.RegisterSubscriberResponse,
            Awaitable[service.RegisterSubscriberResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def unregister_subscriber(
        self,
    ) -> Callable[
        [service.UnregisterSubscriberRequest],
        Union[
            service.UnregisterSubscriberResponse,
            Awaitable[service.UnregisterSubscriberResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_subscribers(
        self,
    ) -> Callable[
        [service.ListSubscribersRequest],
        Union[
            service.ListSubscribersResponse, Awaitable[service.ListSubscribersResponse]
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_entitlement_changes(
        self,
    ) -> Callable[
        [service.ListEntitlementChangesRequest],
        Union[
            service.ListEntitlementChangesResponse,
            Awaitable[service.ListEntitlementChangesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_operations(
        self,
    ) -> Callable[
        [operations_pb2.ListOperationsRequest],
        Union[
            operations_pb2.ListOperationsResponse,
            Awaitable[operations_pb2.ListOperationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_operation(
        self,
    ) -> Callable[
        [operations_pb2.GetOperationRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def cancel_operation(
        self,
    ) -> Callable[[operations_pb2.CancelOperationRequest], None,]:
        raise NotImplementedError()

    @property
    def delete_operation(
        self,
    ) -> Callable[[operations_pb2.DeleteOperationRequest], None,]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("CloudChannelServiceTransport",)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.channel_v1.types import entitlements

__protobuf__ = proto.module(
    package="google.cloud.channel.v1",
    manifest={
        "EntitlementChange",
    },
)


class EntitlementChange(proto.Message):
    r"""Change event entry for Entitlement order history

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        suspension_reason (google.cloud.channel_v1.types.Entitlement.SuspensionReason):
            Suspension reason for the Entitlement.

            This field is a member of `oneof`_ ``change_reason``.
        cancellation_reason (google.cloud.channel_v1.types.EntitlementChange.CancellationReason):
            Cancellation reason for the Entitlement.

            This field is a member of `oneof`_ ``change_reason``.
        activation_reason (google.cloud.channel_v1.types.EntitlementChange.ActivationReason):
            The Entitlement's activation reason

            This field is a member of `oneof`_ ``change_reason``.
        other_change_reason (str):
            e.g. purchase_number change reason, entered by CRS.

            This field is a member of `oneof`_ ``change_reason``.
        entitlement (str):
            Required. Resource name of an entitlement in the form:
            accounts/{account_id}/customers/{customer_id}/entitlements/{entitlement_id}
        offer (str):
            Required. Resource name of the Offer at the time of change.
            Takes the form: accounts/{account_id}/offers/{offer_id}.
        provisioned_service (google.cloud.channel_v1.types.ProvisionedService):
            Service provisioned for an Entitlement.
        change_type (google.cloud.channel_v1.types.EntitlementChange.ChangeType):
            The change action type.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            The submitted time of the change.
        operator_type (google.cloud.channel_v1.types.EntitlementChange.OperatorType):
            Operator type responsible for the change.
        parameters (MutableSequence[google.cloud.channel_v1.types.Parameter]):
            Extended parameters, such as: purchase_order_number,
            gcp_details; internal_correlation_id,
            long_running_operation_id, order_id; etc.
        operator (str):
            Human-readable identifier that shows what operator made a
            change. When the operator_type is RESELLER, this is the
            user's email address. For all other operator types, this is
            empty.
    """

    class ChangeType(proto.Enum):
        r"""Specifies the type of change action

        Values:
            CHANGE_TYPE_UNSPECIFIED (0):
                Not used.
            CREATED (1):
                New Entitlement was created.
            PRICE_PLAN_SWITCHED (3):
                Price plan associated with an Entitlement was
                changed.
            COMMITMENT_CHANGED (4):
                Number of seats committed for a commitment
                Entitlement was changed.
            RENEWED (5):
                An annual Entitlement was renewed.
            SUSPENDED (6):
                Entitlement was suspended.
            ACTIVATED (7):
                Entitlement was activated.
            CANCELLED (8):
                Entitlement was cancelled.
            SKU_CHANGED (9):
                Entitlement was upgraded or downgraded for
                ex. from Google Workspace Business Standard to
                Google Workspace Business Plus.
            RENEWAL_SETTING_CHANGED (10):
                The settings for renewal of an Entitlement
                have changed.
            PAID_SUBSCRIPTION_STARTED (11):
                Use for Google Workspace subscription.
                Either a trial was converted to a paid
                subscription or a new subscription with no trial
                is created.
            LICENSE_CAP_CHANGED (12):
                License cap was changed for the entitlement.
            SUSPENSION_DETAILS_CHANGED (13):
                The suspension details have changed (but it
                is still suspended).
            TRIAL_END_DATE_EXTENDED (14):
                The trial end date was extended.
            TRIAL_STARTED (15):
                Entitlement started trial.
        """
        CHANGE_TYPE_UNSPECIFIED = 0
        CREATED = 1
        PRICE_PLAN_SWITCHED = 3
        COMMITMENT_CHANGED = 4
        RENEWED = 5
        SUSPENDED = 6
        ACTIVATED = 7
        CANCELLED = 8
        SKU_CHANGED = 9
        RENEWAL_SETTING_CHANGED = 10
        PAID_SUBSCRIPTION_STARTED = 11
        LICENSE_CAP_CHANGED = 12
        SUSPENSION_DETAILS_CHANGED = 13
        TRIAL_END_DATE_EXTENDED = 14
        TRIAL_STARTED = 15

    class OperatorType(proto.Enum):
        r"""Specifies the type of operator responsible for the change

        Values:
            OPERATOR_TYPE_UNSPECIFIED (0):
                Not used.
            CUSTOMER_SERVICE_REPRESENTATIVE (1):
                Customer service representative.
            SYSTEM (2):
                System auto job.
            CUSTOMER (3):
                Customer user.
            RESELLER (4):
                Reseller user.
        """
        OPERATOR_TYPE_UNSPECIFIED = 0
        CUSTOMER_SERVICE_REPRESENTATIVE = 1
        SYSTEM = 2
        CUSTOMER = 3
        RESELLER = 4

    class CancellationReason(proto.Enum):
        r"""Cancellation reason for the entitlement

        Values:
            CANCELLATION_REASON_UNSPECIFIED (0):
                Not used.
            SERVICE_TERMINATED (1):
                Reseller triggered a cancellation of the
                service.
            RELATIONSHIP_ENDED (2):
                Relationship between the reseller and
                customer has ended due to a transfer.
            PARTIAL_TRANSFER (3):
                Entitlement transferred away from reseller
                while still keeping other entitlement(s) with
                the reseller.
        """
        CANCELLATION_REASON_UNSPECIFIED = 0
        SERVICE_TERMINATED = 1
        RELATIONSHIP_ENDED = 2
        PARTIAL_TRANSFER = 3

    class ActivationReason(proto.Enum):
        r"""The Entitlement's activation reason

        Values:
            ACTIVATION_REASON_UNSPECIFIED (0):
                Not used.
            RESELLER_REVOKED_SUSPENSION (1):
                Reseller reactivated a suspended Entitlement.
            CUSTOMER_ACCEPTED_PENDING_TOS (2):
                Customer accepted pending terms of service.
            RENEWAL_SETTINGS_CHANGED (3):
                Reseller updated the renewal settings on an
                entitlement that was suspended due to
                cancellation, and this update reactivated the
                entitlement.
            OTHER_ACTIVATION_REASON (100):
                Other reasons (Activated temporarily for
                cancellation, added a payment plan to a trial
                entitlement, etc.)
        """
        ACTIVATION_REASON_UNSPECIFIED = 0
        RESELLER_REVOKED_SUSPENSION = 1
        CUSTOMER_ACCEPTED_PENDING_TOS = 2
        RENEWAL_SETTINGS_CHANGED = 3
        OTHER_ACTIVATION_REASON = 100

    suspension_reason: entitlements.Entitlement.SuspensionReason = proto.Field(
        proto.ENUM,
        number=9,
        oneof="change_reason",
        enum=entitlements.Entitlement.SuspensionReason,
    )
    cancellation_reason: CancellationReason = proto.Field(
        proto.ENUM,
        number=10,
        oneof="change_reason",
        enum=CancellationReason,
    )
    activation_reason: ActivationReason = proto.Field(
        proto.ENUM,
        number=11,
        oneof="change_reason",
        enum=ActivationReason,
    )
    other_change_reason: str = proto.Field(
        proto.STRING,
        number=100,
        oneof="change_reason",
    )
    entitlement: str = proto.Field(
        proto.STRING,
        number=1,
    )
    offer: str = proto.Field(
        proto.STRING,
        number=2,
    )
    provisioned_service: entitlements.ProvisionedService = proto.Field(
        proto.MESSAGE,
        number=3,
        message=entitlements.ProvisionedService,
    )
    change_type: ChangeType = proto.Field(
        proto.ENUM,
        number=4,
        enum=ChangeType,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )
    operator_type: OperatorType = proto.Field(
        proto.ENUM,
        number=6,
        enum=OperatorType,
    )
    parameters: MutableSequence[entitlements.Parameter] = proto.RepeatedField(
        proto.MESSAGE,
        number=8,
        message=entitlements.Parameter,
    )
    operator: str = proto.Field(
        proto.STRING,
        number=12,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.channel.v1",
    manifest={
        "CustomerEvent",
        "EntitlementEvent",
        "SubscriberEvent",
    },
)


class CustomerEvent(proto.Message):
    r"""Represents Pub/Sub message content describing customer
    update.

    Attributes:
        customer (str):
            Resource name of the customer. Format:
            accounts/{account_id}/customers/{customer_id}
        event_type (google.cloud.channel_v1.types.CustomerEvent.Type):
            Type of event which happened on the customer.
    """

    class Type(proto.Enum):
        r"""Type of customer event.

        Values:
            TYPE_UNSPECIFIED (0):
                Not used.
            PRIMARY_DOMAIN_CHANGED (1):
                Primary domain for customer was changed.
            PRIMARY_DOMAIN_VERIFIED (2):
                Primary domain of the customer has been
                verified.
        """
        TYPE_UNSPECIFIED = 0
        PRIMARY_DOMAIN_CHANGED = 1
        PRIMARY_DOMAIN_VERIFIED = 2

    customer: str = proto.Field(
        proto.STRING,
        number=1,
    )
    event_type: Type = proto.Field(
        proto.ENUM,
        number=2,
        enum=Type,
    )


class EntitlementEvent(proto.Message):
    r"""Represents Pub/Sub message content describing entitlement
    update.

    Attributes:
        entitlement (str):
            Resource name of an entitlement of the form:
            accounts/{account_id}/customers/{customer_id}/entitlements/{entitlement_id}
        event_type (google.cloud.channel_v1.types.EntitlementEvent.Type):
            Type of event which happened on the
            entitlement.
    """

    class Type(proto.Enum):
        r"""Type of entitlement event.

        Values:
            TYPE_UNSPECIFIED (0):
                Not used.
            CREATED (1):
                A new entitlement was created.
            PRICE_PLAN_SWITCHED (3):
                The offer type associated with an entitlement
                was changed. This is not triggered if an
                entitlement converts from a commit offer to a
                flexible offer as part of a renewal.
            COMMITMENT_CHANGED (4):
                Annual commitment for a commit plan was
                changed.
            RENEWED (5):
                An annual entitlement was renewed.
            SUSPENDED (6):
                Entitlement was suspended.
            ACTIVATED (7):
                Entitlement was unsuspended.
            CANCELLED (8):
                Entitlement was cancelled.
            SKU_CHANGED (9):
                Entitlement was upgraded or downgraded (e.g.
                from Google Workspace Business Standard to
                Google Workspace Business Plus).
            RENEWAL_SETTING_CHANGED (10):
                The renewal settings of an entitlement has
                changed.
            PAID_SERVICE_STARTED (11):
                Paid service has started on trial
                entitlement.
            LICENSE_ASSIGNMENT_CHANGED (12):
                License was assigned to or revoked from a
                user.
            LICENSE_CAP_CHANGED (13):
                License cap was changed for the entitlement.
        """
        TYPE_UNSPECIFIED = 0
        CREATED = 1
        PRICE_PLAN_SWITCHED = 3
        COMMITMENT_CHANGED = 4
        RENEWED = 5
        SUSPENDED = 6
        ACTIVATED = 7
        CANCELLED = 8
        SKU_CHANGED = 9
        RENEWAL_SETTING_CHANGED = 10
        PAID_SERVICE_STARTED = 11
        LICENSE_ASSIGNMENT_CHANGED = 12
        LICENSE_CAP_CHANGED = 13

    entitlement: str = proto.Field(
        proto.STRING,
        number=1,
    )
    event_type: Type = proto.Field(
        proto.ENUM,
        number=2,
        enum=Type,
    )


class SubscriberEvent(proto.Message):
    r"""Represents information which resellers will get as part of
    notification from Pub/Sub.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        customer_event (google.cloud.channel_v1.types.CustomerEvent):
            Customer event sent as part of Pub/Sub event
            to partners.

            This field is a member of `oneof`_ ``event``.
        entitlement_event (google.cloud.channel_v1.types.EntitlementEvent):
            Entitlement event sent as part of Pub/Sub
            event to partners.

            This field is a member of `oneof`_ ``event``.
    """

    customer_event: "CustomerEvent" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="event",
        message="CustomerEvent",
    )
    entitlement_event: "EntitlementEvent" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="event",
        message="EntitlementEvent",
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .billing_accounts import BillingAccount
from .channel_partner_links import (
    ChannelPartnerLink,
    ChannelPartnerLinkState,
    ChannelPartnerLinkView,
)
from .common import AdminUser, CloudIdentityInfo, EduData, Value
from .customers import ContactInfo, Customer
from .entitlement_changes import EntitlementChange
from .entitlements import (
    AssociationInfo,
    CommitmentSettings,
    Entitlement,
    Parameter,
    ProvisionedService,
    RenewalSettings,
    TransferableSku,
    TransferEligibility,
    TrialSettings,
)
from .offers import (
    Constraints,
    CustomerConstraints,
    Offer,
    ParameterDefinition,
    PaymentPlan,
    PaymentType,
    Period,
    PeriodType,
    Plan,
    Price,
    PriceByResource,
    PricePhase,
    PriceTier,
    PromotionalOrderType,
    ResourceType,
)
from .operations import OperationMetadata
from .products import MarketingInfo, Media, MediaType, Product, Sku
from .reports_service import (
    Column,
    DateRange,
    FetchReportResultsRequest,
    FetchReportResultsResponse,
    ListReportsRequest,
    ListReportsResponse,
    Report,
    ReportJob,
    ReportResultsMetadata,
    ReportStatus,
    ReportValue,
    Row,
    RunReportJobRequest,
    RunReportJobResponse,
)
from .repricing import (
    ChannelPartnerRepricingConfig,
    ConditionalOverride,
    CustomerRepricingConfig,
    PercentageAdjustment,
    RebillingBasis,
    RepricingAdjustment,
    RepricingCondition,
    RepricingConfig,
    SkuGroupCondition,
)
from .service import (
    ActivateEntitlementRequest,
    BillableSku,
    BillingAccountPurchaseInfo,
    CancelEntitlementRequest,
    ChangeOfferRequest,
    ChangeParametersRequest,
    ChangeRenewalSettingsRequest,
    CheckCloudIdentityAccountsExistRequest,
    CheckCloudIdentityAccountsExistResponse,
    CloudIdentityCustomerAccount,
    CreateChannelPartnerLinkRequest,
    CreateChannelPartnerRepricingConfigRequest,
    CreateCustomerRepricingConfigRequest,
    CreateCustomerRequest,
    CreateEntitlementRequest,
    DeleteChannelPartnerRepricingConfigRequest,
    DeleteCustomerRepricingConfigRequest,
    DeleteCustomerRequest,
    GetChannelPartnerLinkRequest,
    GetChannelPartnerRepricingConfigRequest,
    GetCustomerRepricingConfigRequest,
    GetCustomerRequest,
    GetEntitlementRequest,
    ImportCustomerRequest,
    ListChannelPartnerLinksRequest,
    ListChannelPartnerLinksResponse,
    ListChannelPartnerRepricingConfigsRequest,
    ListChannelPartnerRepricingConfigsResponse,
    ListCustomerRepricingConfigsRequest,
    ListCustomerRepricingConfigsResponse,
    ListCustomersRequest,
    ListCustomersResponse,
    ListEntitlementChangesRequest,
    ListEntitlementChangesResponse,
    ListEntitlementsRequest,
    ListEntitlementsResponse,
    ListOffersRequest,
    ListOffersResponse,
    ListProductsRequest,
    ListProductsResponse,
    ListPurchasableOffersRequest,
    ListPurchasableOffersResponse,
    ListPurchasableSkusRequest,
    ListPurchasableSkusResponse,
    ListSkuGroupBillableSkusRequest,
    ListSkuGroupBillableSkusResponse,
    ListSkuGroupsRequest,
    ListSkuGroupsResponse,
    ListSkusRequest,
    ListSkusResponse,
    ListSubscribersRequest,
    ListSubscribersResponse,
    ListTransferableOffersRequest,
    ListTransferableOffersResponse,
    ListTransferableSkusRequest,
    ListTransferableSkusResponse,
    LookupOfferRequest,
    ProvisionCloudIdentityRequest,
    PurchasableOffer,
    PurchasableSku,
    QueryEligibleBillingAccountsRequest,
    QueryEligibleBillingAccountsResponse,
    RegisterSubscriberRequest,
    RegisterSubscriberResponse,
    SkuGroup,
    SkuPurchaseGroup,
    StartPaidServiceRequest,
    SuspendEntitlementRequest,
    TransferableOffer,
    TransferEntitlementsRequest,
    TransferEntitlementsResponse,
    TransferEntitlementsToGoogleRequest,
    UnregisterSubscriberRequest,
    UnregisterSubscriberResponse,
    UpdateChannelPartnerLinkRequest,
    UpdateChannelPartnerRepricingConfigRequest,
    UpdateCustomerRepricingConfigRequest,
    UpdateCustomerRequest,
)
from .subscriber_event import CustomerEvent, EntitlementEvent, SubscriberEvent

__all__ = (
    "BillingAccount",
    "ChannelPartnerLink",
    "ChannelPartnerLinkState",
    "ChannelPartnerLinkView",
    "AdminUser",
    "CloudIdentityInfo",
    "EduData",
    "Value",
    "ContactInfo",
    "Customer",
    "EntitlementChange",
    "AssociationInfo",
    "CommitmentSettings",
    "Entitlement",
    "Parameter",
    "ProvisionedService",
    "RenewalSettings",
    "TransferableSku",
    "TransferEligibility",
    "TrialSettings",
    "Constraints",
    "CustomerConstraints",
    "Offer",
    "ParameterDefinition",
    "Period",
    "Plan",
    "Price",
    "PriceByResource",
    "PricePhase",
    "PriceTier",
    "PaymentPlan",
    "PaymentType",
    "PeriodType",
    "PromotionalOrderType",
    "ResourceType",
    "OperationMetadata",
    "MarketingInfo",
    "Media",
    "Product",
    "Sku",
    "MediaType",
    "Column",
    "DateRange",
    "FetchReportResultsRequest",
    "FetchReportResultsResponse",
    "ListReportsRequest",
    "ListReportsResponse",
    "Report",
    "ReportJob",
    "ReportResultsMetadata",
    "ReportStatus",
    "ReportValue",
    "Row",
    "RunReportJobRequest",
    "RunReportJobResponse",
    "ChannelPartnerRepricingConfig",
    "ConditionalOverride",
    "CustomerRepricingConfig",
    "PercentageAdjustment",
    "RepricingAdjustment",
    "RepricingCondition",
    "RepricingConfig",
    "SkuGroupCondition",
    "RebillingBasis",
    "ActivateEntitlementRequest",
    "BillableSku",
    "BillingAccountPurchaseInfo",
    "CancelEntitlementRequest",
    "ChangeOfferRequest",
    "ChangeParametersRequest",
    "ChangeRenewalSettingsRequest",
    "CheckCloudIdentityAccountsExistRequest",
    "CheckCloudIdentityAccountsExistResponse",
    "CloudIdentityCustomerAccount",
    "CreateChannelPartnerLinkRequest",
    "CreateChannelPartnerRepricingConfigRequest",
    "CreateCustomerRepricingConfigRequest",
    "CreateCustomerRequest",
    "CreateEntitlementRequest",
    "DeleteChannelPartnerRepricingConfigRequest",
    "DeleteCustomerRepricingConfigRequest",
    "DeleteCustomerRequest",
    "GetChannelPartnerLinkRequest",
    "GetChannelPartnerRepricingConfigRequest",
    "GetCustomerRepricingConfigRequest",
    "GetCustomerRequest",
    "GetEntitlementRequest",
    "ImportCustomerRequest",
    "ListChannelPartnerLinksRequest",
    "ListChannelPartnerLinksResponse",
    "ListChannelPartnerRepricingConfigsRequest",
    "ListChannelPartnerRepricingConfigsResponse",
    "ListCustomerRepricingConfigsRequest",
    "ListCustomerRepricingConfigsResponse",
    "ListCustomersRequest",
    "ListCustomersResponse",
    "ListEntitlementChangesRequest",
    "ListEntitlementChangesResponse",
    "ListEntitlementsRequest",
    "ListEntitlementsResponse",
    "ListOffersRequest",
    "ListOffersResponse",
    "ListProductsRequest",
    "ListProductsResponse",
    "ListPurchasableOffersRequest",
    "ListPurchasableOffersResponse",
    "ListPurchasableSkusRequest",
    "ListPurchasableSkusResponse",
    "ListSkuGroupBillableSkusRequest",
    "ListSkuGroupBillableSkusResponse",
    "ListSkuGroupsRequest",
    "ListSkuGroupsResponse",
    "ListSkusRequest",
    "ListSkusResponse",
    "ListSubscribersRequest",
    "ListSubscribersResponse",
    "ListTransferableOffersRequest",
    "ListTransferableOffersResponse",
    "ListTransferableSkusRequest",
    "ListTransferableSkusResponse",
    "LookupOfferRequest",
    "ProvisionCloudIdentityRequest",
    "PurchasableOffer",
    "PurchasableSku",
    "QueryEligibleBillingAccountsRequest",
    "QueryEligibleBillingAccountsResponse",
    "RegisterSubscriberRequest",
    "RegisterSubscriberResponse",
    "SkuGroup",
    "SkuPurchaseGroup",
    "StartPaidServiceRequest",
    "SuspendEntitlementRequest",
    "TransferableOffer",
    "TransferEntitlementsRequest",
    "TransferEntitlementsResponse",
    "TransferEntitlementsToGoogleRequest",
    "UnregisterSubscriberRequest",
    "UnregisterSubscriberResponse",
    "UpdateChannelPartnerLinkRequest",
    "UpdateChannelPartnerRepricingConfigRequest",
    "UpdateCustomerRepricingConfigRequest",
    "UpdateCustomerRequest",
    "CustomerEvent",
    "EntitlementEvent",
    "SubscriberEvent",
)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import io
import os
import re

import setuptools  # type: ignore

package_root = os.path.abspath(os.path.dirname(__file__))

name = "google-cloud-channel"


description = "Google Cloud Channel API client library"

version = None

with open(os.path.join(package_root, "google/cloud/channel/gapic_version.py")) as fp:
    version_candidates = re.findall(r"(?<=\")\d+.\d+.\d+(?=\")", fp.read())
    assert len(version_candidates) == 1
    version = version_candidates[0]

if version[0] == "0":
    release_status = "Development Status :: 4 - Beta"
else:
    release_status = "Development Status :: 5 - Production/Stable"

dependencies = [
    "google-api-core[grpc] >= 1.34.1, <3.0.0,!=2.0.*,!=2.1.*,!=2.2.*,!=2.3.*,!=2.4.*,!=2.5.*,!=2.6.*,!=2.7.*,!=2.8.*,!=2.9.*,!=2.10.*",
    # Exclude incompatible versions of `google-auth`
    # See https://github.com/googleapis/google-cloud-python/issues/12364
    "google-auth >= 2.14.1, <3.0.0,!=2.24.0,!=2.25.0",
    "proto-plus >= 1.22.3, <2.0.0",
    "proto-plus >= 1.25.0, <2.0.0; python_version >= '3.13'",
    "protobuf>=3.20.2,<7.0.0,!=4.21.0,!=4.21.1,!=4.21.2,!=4.21.3,!=4.21.4,!=4.21.5",
]
extras = {}
url = "https://github.com/googleapis/google-cloud-python/tree/main/packages/google-cloud-channel"

package_root = os.path.abspath(os.path.dirname(__file__))

readme_filename = os.path.join(package_root, "README.rst")
with io.open(readme_filename, encoding="utf-8") as readme_file:
    readme = readme_file.read()

packages = [
    package
    for package in setuptools.find_namespace_packages()
    if package.startswith("google")
]

setuptools.setup(
    name=name,
    version=version,
    description=description,
    long_description=readme,
    author="Google LLC",
    author_email="googleapis-packages@google.com",
    license="Apache 2.0",
    url=url,
    classifiers=[
        release_status,
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Operating System :: OS Independent",
        "Topic :: Internet",
    ],
    platforms="Posix; MacOS X; Windows",
    packages=packages,
    python_requires=">=3.7",
    install_requires=dependencies,
    extras_require=extras,
    include_package_data=True,
    zip_safe=False,
)
